==> mule-standalone-3.0.0.tar.gz: org/mule/test/integration/client/MuleClientAxisTestCase.java <==
/*
 * $Id: MuleClientAxisTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.test.integration.client;

import org.mule.api.MuleMessage;
import org.mule.module.client.MuleClient;
import org.mule.tck.FunctionalTestCase;
import org.mule.tck.testmodels.services.Person;

public class MuleClientAxisTestCase extends FunctionalTestCase
{

    @Override
    protected String getConfigResources()
    {
        return "org/mule/test/integration/client/axis-client-test-mule-config.xml";
    }

    public void testRequestResponse() throws Throwable
    {
        MuleClient client = new MuleClient(muleContext);

        MuleMessage result = client.send("axis:http://localhost:38104/mule/services/mycomponent2?method=echo",
            "test", null);
        assertNotNull(result);
        assertEquals("test", result.getPayloadAsString());
    }

    public void testRequestResponseComplex() throws Exception
    {
        MuleClient client = new MuleClient(muleContext);

        MuleMessage result = client.send(
            "axis:http://localhost:38104/mule/services/mycomponent3?method=getPerson", "Fred", null);
        assertNotNull(result);
        logger.debug(result.getPayload());
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Fred", ((Person)result.getPayload()).getFirstName());
        assertEquals("Flintstone", ((Person)result.getPayload()).getLastName());
    }

    public void testRequestResponseComplex2() throws Exception
    {
        MuleClient client = new MuleClient(muleContext);

        String[] args = new String[]{"Betty", "Rubble"};
        MuleMessage result = client.send(
            "axis:http://localhost:38104/mule/services/mycomponent3?method=addPerson", args, null);
        assertNotNull(result);
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Betty", ((Person)result.getPayload()).getFirstName());
        assertEquals("Rubble", ((Person)result.getPayload()).getLastName());

        // do a receive
        result = client.send("axis:http://localhost:38104/mule/services/mycomponent3?method=getPerson",
            "Betty", null);
        assertNotNull(result);
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Betty", ((Person)result.getPayload()).getFirstName());
        assertEquals("Rubble", ((Person)result.getPayload()).getLastName());

    }

    public void testRequestWithComplexArg() throws Exception
    {
        MuleClient client = new MuleClient(muleContext);
        Person person = new Person("Joe", "Blow");
        String uri = "axis:http://localhost:38104/mule/services/mycomponent3?method=addPerson";
        client.send(uri, person, null);
        uri = "axis:http://localhost:38104/mule/services/mycomponent3?method=getPerson";
        MuleMessage result = client.send(uri, "Joe", null);
        assertNotNull(result);
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Joe", ((Person)result.getPayload()).getFirstName());
        assertEquals("Blow", ((Person)result.getPayload()).getLastName());
    }

}

==> mule-standalone-3.0.1.tar.gz: org/mule/test/integration/client/MuleClientAxisTestCase.java <==
/*
 * $Id: MuleClientAxisTestCase.java 19856 2010-10-06 21:36:13Z dzapata $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.test.integration.client;

import org.mule.api.MuleMessage;
import org.mule.api.endpoint.InboundEndpoint;
import org.mule.module.client.MuleClient;
import org.mule.tck.DynamicPortTestCase;
import org.mule.tck.testmodels.services.Person;

public class MuleClientAxisTestCase extends DynamicPortTestCase
{

    @Override
    protected String getConfigResources()
    {
        return "org/mule/test/integration/client/axis-client-test-mule-config.xml";
    }

    /**
     * Get the Mule address for a Mule client call
     * 
     * @param muleClient The MuleClient instance to use
     * @param endpointName The inbound endpoint which contains the address
     * @return A String of the 'Mule' address, which in this case should include
     *         'axis" + 'http://<url>'
     */
    private String getMuleAddress(MuleClient muleClient, String inboundEndpointName)
    {
        return ((InboundEndpoint) muleClient.getMuleContext().getRegistry().lookupObject(inboundEndpointName)).getProtocol()
               + ":"
               + ((InboundEndpoint) muleClient.getMuleContext().getRegistry().lookupObject(
                   inboundEndpointName)).getAddress();
    }
    
    public void testRequestResponse() throws Throwable
    {
        MuleClient client = new MuleClient(muleContext);
        MuleMessage result = client.send(getMuleAddress(client, "inMyComponent2") + "/mycomponent2?method=echo",
            "test", null);
        assertNotNull(result);
        assertEquals("test", result.getPayloadAsString());
    }

    public void testRequestResponseComplex() throws Exception
    {
        MuleClient client = new MuleClient(muleContext);

        MuleMessage result = client.send(
            getMuleAddress(client, "inMyComponent3") + "/mycomponent3?method=getPerson", "Fred", null);
        assertNotNull(result);
        logger.debug(result.getPayload());
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Fred", ((Person)result.getPayload()).getFirstName());
        assertEquals("Flintstone", ((Person)result.getPayload()).getLastName());
    }

    public void testRequestResponseComplex2() throws Exception
    {
        MuleClient client = new MuleClient(muleContext);

        String[] args = new String[]{"Betty", "Rubble"};
        MuleMessage result = client.send(
            getMuleAddress(client, "inMyComponent3") + "/mycomponent3?method=addPerson", args, null);
        assertNotNull(result);
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Betty", ((Person)result.getPayload()).getFirstName());
        assertEquals("Rubble", ((Person)result.getPayload()).getLastName());

        // do a receive
        result = client.send(getMuleAddress(client, "inMyComponent3") + "/mycomponent3?method=getPerson",
            "Betty", null);
        assertNotNull(result);
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Betty", ((Person)result.getPayload()).getFirstName());
        assertEquals("Rubble", ((Person)result.getPayload()).getLastName());

    }

    public void testRequestWithComplexArg() throws Exception
    {
        MuleClient client = new MuleClient(muleContext);
        Person person = new Person("Joe", "Blow");
        String uri = getMuleAddress(client, "inMyComponent3") + "/mycomponent3?method=addPerson";
        client.send(uri, person, null);
        uri = getMuleAddress(client, "inMyComponent3") +  "/mycomponent3?method=getPerson";
        MuleMessage result = client.send(uri, "Joe", null);
        assertNotNull(result);
        assertTrue(result.getPayload() instanceof Person);
        assertEquals("Joe", ((Person)result.getPayload()).getFirstName());
        assertEquals("Blow", ((Person)result.getPayload()).getLastName());
    }

    @Override
    protected int getNumPortsToFind()
    {
        return 3;
    }

}
